"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var processString_1 = require("./processString");
describe('processString', function () {
    describe('should correctly parse url', function () {
        test('if text only contains one url', function () {
            var onlyUrl = '[Homepage](https://kylerwong.dev/)';
            expect(processString_1.default(onlyUrl)).toStrictEqual(['[Homepage](https://kylerwong.dev/)']);
        });
        test('if text contains multiple urls', function () {
            var onlyUrl = '[Homepage](https://kylerwong.dev/) [Google](https://google.com)';
            expect(processString_1.default(onlyUrl)).toStrictEqual([
                '[Homepage](https://kylerwong.dev/)',
                ' ',
                '[Google](https://google.com)',
            ]);
        });
        test('if text contains a mix of plain texts and empty urls', function () {
            var text = 'I like to document about my life - occasionally on [WordPress](), and actively on [Dayre](). You can also find me on [Facebook]() and [Instagram]().';
            expect(processString_1.default(text)).toStrictEqual([
                'I like to document about my life - occasionally on ',
                '[WordPress]()',
                ', and actively on ',
                '[Dayre]()',
                '. You can also find me on ',
                '[Facebook]()',
                ' and ',
                '[Instagram]()',
                '.',
            ]);
        });
        test('if text contains a mix of plain texts and urls', function () {
            var text = 'I like to document about my life - occasionally on [WordPress](https://rainbowparachutes.wordpress.com), and actively on [Dayre](https://dayre.me/huiyingying). You can also find me on [Facebook](https://www.facebook.com/phanghuiying123) and [Instagram](https://www.instagram.com/p.huiying/).';
            expect(processString_1.default(text)).toStrictEqual([
                'I like to document about my life - occasionally on ',
                '[WordPress](https://rainbowparachutes.wordpress.com)',
                ', and actively on ',
                '[Dayre](https://dayre.me/huiyingying)',
                '. You can also find me on ',
                '[Facebook](https://www.facebook.com/phanghuiying123)',
                ' and ',
                '[Instagram](https://www.instagram.com/p.huiying/)',
                '.',
            ]);
        });
    });
});
